Documentation
¶
Index ¶
- Constants
- Variables
- func CaptureAndDisplayTogether(r1 io.Reader, r2 io.Reader, offset int, label1 string, label2 string)
- func CaptureAndOutput(r io.Reader)
- func Execute()
- func GetRawProfileFromJwt(jwt string) ([]byte, error)
- func LoadBiomeAddress() error
- func LoadProfile() error
- func PadString(str string, target int) string
- type BuildStatus
- type Config
- type Contracts
- type Node
- type Organization
- type Profile
- type Resources
- type Spinner
- type SqlQueryRequestPayload
- type WebsocketConnection
- type WebsocketTransport
Constants ¶
const (
// VERSION is set during build
VERSION = "DEFAULT_VERSION"
)
Variables ¶
var (
ErrorMethodNotAllowed = errors.New("Method not allowed")
)
var RootCmd = &cobra.Command{ Use: "whiteblock", Version: VERSION, Short: "Create and test blockchains", Long: `This application will deploy a blockchain, create nodes, and allow those nodes to interact in the network. Documentation, usages, and exmaples can be found at https://docs.whiteblock.io/. `, }
Functions ¶
func CaptureAndDisplayTogether ¶
func CaptureAndDisplayTogether(r1 io.Reader, r2 io.Reader, offset int, label1 string, label2 string)
Display the contents of two readers, line by line, together
func CaptureAndOutput ¶
func GetRawProfileFromJwt ¶
func LoadBiomeAddress ¶
func LoadBiomeAddress() error
func LoadProfile ¶
func LoadProfile() error
Types ¶
type BuildStatus ¶
type Config ¶
type Config struct {
Servers []int `json:"servers"`
Blockchain string `json:"blockchain"`
Nodes int `json:"nodes"`
Images []string `json:"images"`
Resources []Resources `json:"resources"`
Params map[string]interface{} `json:"params"`
Environments []map[string]string `json:"environments"`
Files []map[string]string `json:"files"`
Logs []map[string]string `json:"logs"`
Extras map[string]interface{} `json:"extras"`
}
type Node ¶
type Organization ¶
type Profile ¶
type Profile struct {
Id int `json:"id"`
Organization Organization `json:"organization"`
}
type SqlQueryRequestPayload ¶ added in v1.8.12
type SqlQueryRequestPayload struct {
Q string `json:"q"`
}
type WebsocketConnection ¶
type WebsocketConnection struct {
// contains filtered or unexported fields
}
func (*WebsocketConnection) Close ¶
func (wsc *WebsocketConnection) Close()
func (*WebsocketConnection) GetMessage ¶
func (wsc *WebsocketConnection) GetMessage() (message string, err error)
func (*WebsocketConnection) PingParams ¶
func (wsc *WebsocketConnection) PingParams() (interval, timeout time.Duration)
func (*WebsocketConnection) WriteMessage ¶
func (wsc *WebsocketConnection) WriteMessage(message string) error
type WebsocketTransport ¶
type WebsocketTransport struct {
PingInterval time.Duration
PingTimeout time.Duration
ReceiveTimeout time.Duration
SendTimeout time.Duration
BufferSize int
RequestHeader http.Header
}
func GetDefaultWebsocketTransport ¶
func GetDefaultWebsocketTransport() *WebsocketTransport
* Returns websocket connection with default params
func (*WebsocketTransport) Connect ¶
func (wst *WebsocketTransport) Connect(url string) (conn transport.Connection, err error)
func (*WebsocketTransport) HandleConnection ¶
func (wst *WebsocketTransport) HandleConnection( w http.ResponseWriter, r *http.Request) (conn transport.Connection, err error)
func (*WebsocketTransport) Serve ¶
func (wst *WebsocketTransport) Serve(w http.ResponseWriter, r *http.Request)
* Websocket connection do not require any additional processing
Source Files
¶
- auto.go
- blockchainSpecifics.go
- build.go
- buildAppend.go
- buildHelpers.go
- config.go
- console.go
- done.go
- exec.go
- export.go
- get.go
- getLogs.go
- gethCMD.go
- iperf.go
- kill.go
- login.go
- man.go
- miners.go
- netconfig.go
- ping.go
- prettyp.go
- profile.go
- remote.go
- restart.go
- root.go
- scp.go
- signal.go
- socketTransport.go
- spinner.go
- sql.go
- ssh.go
- sync.go
- test.go
- transactions.go
- version.go
- webhandler.go
Click to show internal directories.
Click to hide internal directories.